@@ -25,24 +25,25 @@
 #define CONSOLE_H
 
 enum {
-  W_CONSOLE, W_CONSOLE_LBL, W_CONSOLE_TXT,
-  W_CONSOLE_N
+    W_CONSOLE, W_CONSOLE_LBL, W_CONSOLE_TXT,
+    W_CONSOLE_N
 };
 
-extern GtkWidget* w_console[W_CONSOLE_N];
+extern GtkWidget *w_console[W_CONSOLE_N];
 
 void console_create(void);
 void console_show(void);
 void console_hide(void);
 void console_clear(void);
-void console_print(char* s, int tidx);
+void console_print(char *s, int tidx);
 void console_print_size(off_t size, int tidx);
 
-void console_print_stdout(char* s);
-void console_print_stderr(char* s);
-void console_print_spawn(char* s);
+void console_print_stdout(char *s);
+void console_print_stderr(char *s);
+void console_print_spawn(char *s);
 
-int console_savelog(char* filename);
-void console_populate_popup(GtkTextView* tv, GtkMenu* menu, gpointer unused);
+int console_savelog(char *filename);
+void console_populate_popup(GtkTextView * tv, GtkMenu * menu,
+			    gpointer unused);
 
-#endif /* CONSOLE_H */
+#endif				/* CONSOLE_H */
