@@ -25,13 +25,13 @@
 #define PACKAGE_LIST_H
 
 enum {
-  W_PACKAGE_LIST_SCR,
-  W_PACKAGE_LIST,
+    W_PACKAGE_LIST_SCR,
+    W_PACKAGE_LIST,
 
-  W_PACKAGE_LIST_N
+    W_PACKAGE_LIST_N
 };
 
-extern GtkWidget* w_package_list[W_PACKAGE_LIST_N];
+extern GtkWidget *w_package_list[W_PACKAGE_LIST_N];
 extern struct srcinst_string_list package_list;
 
 void package_list_create(void);
@@ -39,10 +39,14 @@ void package_list_fill(void);
 void package_list_update(void);
 
 
-void package_list_row_activated(GtkTreeView* tree, GtkTreePath* path, GtkTreeViewColumn* column, gpointer user_data);
-void package_list_cursor_changed(GtkTreeView* tree, gpointer user_data);
-gboolean package_list_popup_menu (GtkWidget *widget, gpointer user_data);
-gboolean package_list_button_press_event(GtkWidget* widget, GdkEventButton* event, gpointer user_data);
+void package_list_row_activated(GtkTreeView * tree, GtkTreePath * path,
+				GtkTreeViewColumn * column,
+				gpointer user_data);
+void package_list_cursor_changed(GtkTreeView * tree, gpointer user_data);
+gboolean package_list_popup_menu(GtkWidget * widget, gpointer user_data);
+gboolean package_list_button_press_event(GtkWidget * widget,
+					 GdkEventButton * event,
+					 gpointer user_data);
 
 
-#endif /* PACKAGE_LIST_H */
+#endif				/* PACKAGE_LIST_H */
